@@ -20,10 +20,12 @@ use Moose::Util::TypeConstraints;
 with 'MooseX::Getopt::Usage';
 with 'MooseX::Getopt::Usage::Role::Man';
 
+# For pretty man pages!
+$ENV{TERM}='xterm-256color';
 
 =head1 NAME
 
-HPC::Runner - HPC Runner::Slurm, Runner::MCE and Runner::Threads base class 
+HPC::Runner - HPC Runner::Slurm, Runner::MCE and Runner::Threads base class
 
 =head1 VERSION
 
@@ -31,13 +33,14 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.35';
+our $VERSION = '2.36';
 
 =head1 SYNOPSIS
 
 This is a base class for HPC::Runner::MCE and HPC::Runner:Threads. You should not need to call this module directly.
 
 =head1 EXPORT
+
 =cut
 
 =head1 VARIABLES
@@ -59,6 +62,9 @@ has 'infile' => (
 );
 
 =head2 _set_infile
+
+Internal variable
+
 =cut
 
 sub _set_infile{
@@ -85,6 +91,9 @@ has 'outdir' => (
 );
 
 =head2 _set_outdir
+
+Internal variable
+
 =cut
 
 sub _set_outdir{
@@ -126,9 +135,9 @@ has 'procs' => (
 
 
 has 'verbose' => (
-    is => 'rw', 
+    is => 'rw',
     isa => enum([qw[0 1]]),
-    required => 1, 
+    required => 1,
     default => 1,
     documentation => q{Level of verbosity},
 );
@@ -191,6 +200,9 @@ has 'logname' => (
 =head1 Subroutines
 
 =head2 set_logdir
+
+Set the log directory
+
 =cut
 
 sub set_logdir{
@@ -215,6 +227,9 @@ sub set_logdir{
 }
 
 =head2 set_logfile
+
+Set logfile
+
 =cut
 
 sub set_logfile{
@@ -226,6 +241,9 @@ sub set_logfile{
 }
 
 =head2 init_log
+
+Initialize Log4perl log
+
 =cut
 
 sub init_log {
@@ -275,7 +293,7 @@ sub run_command_mce{
     my $pid = $$;
 
     $DB::single=2;
-    
+
     #Mce doesn't take exitcode to end
     $self->_log_commands($pid);
 
@@ -290,7 +308,7 @@ This example was just about 100% from the following perlmonks discussions.
 
 http://www.perlmonks.org/?node_id=151886
 
-You can use the script at the top to test the runner. Just download it, make it executable, and put it in the infile as 
+You can use the script at the top to test the runner. Just download it, make it executable, and put it in the infile as
 
 perl command.pl 1
 perl command.pl 2
@@ -325,7 +343,7 @@ sub _log_commands {
     die $@ if $@;
     if(! $cmdpid) {
         print "There is no $cmdpid please contact your administrator with the full command given\n";
-        die; 
+        die;
     }
     $infh->autoflush();
 
@@ -338,7 +356,7 @@ sub _log_commands {
 
     $DB::single=2;
 
-# now our child is running, happily printing to 
+# now our child is running, happily printing to
 # its stdout and stderr (our $outfh and $errfh).
 
     my $sel = new IO::Select; # create a select object
@@ -354,7 +372,7 @@ sub _log_commands {
                 $logger->fatal("Error from child: $!");
             } elsif ($len == 0){
                 # Finished reading from this FH because we read
-                # 0 bytes.  Remove this handle from $sel.  
+                # 0 bytes.  Remove this handle from $sel.
                 $sel->remove($fh);
                 next;
             } else { # we read data alright
@@ -387,7 +405,7 @@ sub _log_commands {
 
 
 #__PACKAGE__->meta->make_immutable;
-1; 
+1;
 
 =head1 AUTHOR
 
@@ -431,14 +449,16 @@ L<http://search.cpan.org/dist/Runner-Init/>
 
 =back
 
+=head1 Acknowledgements
 
-=head1 ACKNOWLEDGEMENTS
-
-This module was originally developed at and for Weill Cornell Medical College in Qatar. With approval from WCMC-Q, this information was generalized and put on github, for which the authors would like to express their gratitude.
+This module was originally developed at and for Weill Cornell Medical
+College in Qatar within ITS Advanced Computing Team. With approval from
+WCMC-Q, this information was generalized and put on github, for which
+the authors would like to express their gratitude.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Jillian Rowe.
+Copyright 2014 Weill Cornell Medical College.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
